import React from 'react'
import { View } from 'react-native'
import Ripple from './ripple'
import useMeasurement from './hooks/useMeasurement'
const MoveAwayButton = ({
  children,
  onPressIn,
  onMove,
  onPressOut,
  pressed,
  setPressed,
  style,
  pressedStyle,
  disableRipple,
  rippleColor,
  rippleOpacity = 0.3,
  rippleContainerBorderRadius,
  longPressTimeout,
  moveCancelBuffer: buffer = 10,
  RippleProps,
  ...ViewProps
}) => {
  const { dimensions, setRef } = useMeasurement(buffer)
  const handlePressIn = (e) => {
    if (pressed && onPressIn) {
      onPressIn(e)
    }
    setPressed(true)
  }
  const handleRelease = (e) => {
    if (pressed && onPressOut) {
      onPressOut(e)
    }
  }
  const handleMove = (e) => {
    if (!pressed) {
      return
    }
    if (onMove) {
      onMove(e)
    }
    const { pageX, pageY } = e.nativeEvent
    const { minX, maxX, minY, maxY } = dimensions
    if (pageX < minX || pageX > maxX || pageY < minY || pageY > maxY) {
      setPressed(false)
    }
  }
  return (
    <>
      {disableRipple ? (
        <View
          ref={setRef}
          style={[style, pressed && pressedStyle]}
          onStartShouldSetResponder={() => true}
          onResponderGrant={handlePressIn}
          onResponderMove={handleMove}
          onResponderRelease={handleRelease}
          onResponderTerminationRequest={() => false}
          {...ViewProps}>
          {children}
        </View>
      ) : (
        <Ripple
          containerRef={setRef}
          rippleColor={rippleColor}
          rippleOpacity={rippleOpacity}
          rippleContainerBorderRadius={rippleContainerBorderRadius}
          style={[style, pressed && pressedStyle]}
          onPressIn={handlePressIn}
          onMove={handleMove}
          onPressOut={handleRelease}
          {...ViewProps}
          {...RippleProps}>
          {children}
        </Ripple>
      )}
    </>
  )
}
export default MoveAwayButton
